# assembly_instances
Problem instances for [pb-construction](https://github.com/caelan/pb-construction) and [pychoreo](https://github.com/yijiangh/pychoreo).

See the gallery [here](https://github.com/yijiangh/assembly_instances/tree/master/extrusion/images) for a preview of all the extrusion truss models.